%define py3_libbuilddir %(python3 -c 'import sys; import sysconfig; print("lib.{p}-{v[0]}.{v[1]}".format(p=sysconfig.get_platform(), v=sys.version_info))')

%global pypi_name pillow
%global srcname   Pillow

Name:           python-%{pypi_name}
Version:        9.1.0
Release:        %mkrel 1
Summary:        Python image processing library

Group:          Development/Python
License:        MIT
URL:            https://pypi.org/project/Pillow/#files
Source0:        %{pypi_source}
Patch0:         Pillow-9.1.0-fix-linking.patch
Patch1:         Pillow-9.1.0_sphinxwarn.patch
Patch2:         Pillow-9.1.0-remove-requirements-not-in-M8.patch

#
# Security patches
# P100 -> ...
#
BuildRequires:  pkgconfig(tk)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(imagequant)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  ghostscript
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  tkinter3
BuildRequires:  python3-qt5
BuildRequires:  python3-numpy
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:  python3-sphinx-removed-in
BuildRequires:  python3-sphinx-issues
BuildRequires:  python3-cffi
BuildRequires:  python3-olefile
# for patch2
BuildRequires:  git-core

# For EpsImagePlugin.py
Requires:	ghostscript

Provides:       python-imaging = %{version}-%{release}

%description
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

There are four subpackages: tk (tk interface), qt (PIL image wrapper for Qt),
devel (development) and doc (documentation).

%package -n python3-%{pypi_name}
Group:          Development/Python
Summary:        Python 3 image processing library
Provides:       python3-imaging = %{version}-%{release}
Provides:       python3dist(PIL) = %{version}-%{release}

%description -n python3-%{pypi_name}
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

There are four subpackages: tk (tk interface), qt (PIL image wrapper for Qt),
devel (development) and doc (documentation).

%package -n python3-%{pypi_name}-devel
Summary:        Development files for python3-%{pypi_name}
Group:          Development/C
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-devel
Requires:       libjpeg-devel
Requires:       zlib-devel

%description -n python3-%{pypi_name}-devel
Development files for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-doc
Summary:        Documentation for python3-%{pypi_name}
Group:          Documentation
Requires:       python3-%{pypi_name} = %{version}-%{release}
BuildArch:      noarch

%description -n python3-%{pypi_name}-doc
Documentation for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-tk
Summary:        Tk interface for python3-%{pypi_name}
Group:          System/Libraries
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-tkinter
Conflicts:	python3-%{pypi_name} < 3.0.0-2

%description -n python3-%{pypi_name}-tk
Tk interface for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-qt
Summary:        PIL image wrapper for Qt
Group:          System/Libraries
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-qt5
Conflicts:	python3-%{pypi_name} < 3.0.0-2

%description -n python3-%{pypi_name}-qt
PIL image wrapper for Qt.

%prep
%autosetup -p1 -Sgit -n Pillow-%{version}

# drop bundled egg-info
rm -rf src/Pillow.egg-info/

%build
%py3_build

#for docs
PYTHONPATH=$PWD/build/%py3_libbuilddir make -C docs html SPHINXBUILD=sphinx-build-%python3_version
	
rm -f docs/_build/html/.buildinfo

%install
# Install Python 3 modules
install -d %{buildroot}/%{_includedir}/python%{python3_version}/Imaging
install -m 644 src/libImaging/*.h %{buildroot}/%{_includedir}/python%{python3_version}/Imaging

%py3_install


%check
# Check Python 3 modules
ln -s $PWD/Images $PWD/build/%py3_libbuilddir/Images
cp -R $PWD/Tests $PWD/build/%py3_libbuilddir/Tests
cp -R $PWD/selftest.py $PWD/build/%py3_libbuilddir/selftest.py
pushd build/%py3_libbuilddir
PYTHONPATH=$PWD %{__python3} selftest.py
popd

%files -n python3-%{pypi_name}
%doc README.md CHANGES.rst docs/COPYING
%{python3_sitearch}/*
# These are in subpackages
%exclude %{python3_sitearch}/PIL/_imagingtk*
%exclude %{python3_sitearch}/PIL/ImageTk*
%exclude %{python3_sitearch}/PIL/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/ImageQt*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageTk*
%exclude %{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageQt*

%files -n python3-%{pypi_name}-devel
%{_includedir}/python%{python3_version}/Imaging/

%files -n python3-%{pypi_name}-doc
%doc docs/_build/html

%files -n python3-%{pypi_name}-tk
%{python3_sitearch}/PIL/_imagingtk*
%{python3_sitearch}/PIL/ImageTk*
%{python3_sitearch}/PIL/SpiderImagePlugin*
%{python3_sitearch}/PIL/__pycache__/ImageTk*
%{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*

%files -n python3-%{pypi_name}-qt
%{python3_sitearch}/PIL/ImageQt*
%{python3_sitearch}/PIL/__pycache__/ImageQt*


%changelog
* Sat May 07 2022 papoteur <papoteur> 9.1.0-1.mga8
+ Revision: 1856723
- update to 9.1.0 (mga#29887)

* Wed Sep 22 2021 neoclust <neoclust> 8.1.2-1.1.mga8
+ Revision: 1746197
- Add p106: Fixes CVE-2021-23437 (mga#29481)

* Sun Aug 01 2021 neoclust <neoclust> 8.1.2-1.mga8
+ Revision: 1738430
- New version 8.1.2
- Add patches to fix CVE-2021-25287, CVE-2021-25288, CVE-2021-28675,
  CVE-2021-28676, CVE-2021-28677, CVE-2021-28678, CVE-2021-34552 (mga#29002)

* Sun Jan 24 2021 daviddavid <daviddavid> 8.1.0-2.mga8
+ Revision: 1673190
- add upstream patch to Handle PCX images with an odd stride
  * fix for nml build failure

* Sun Jan 17 2021 neoclust <neoclust> 8.1.0-1.mga8
+ Revision: 1672245
- New version  8.1.0 (mga#28137)

* Sun Nov 08 2020 guillomovitch <guillomovitch> 8.0.1-1.mga8
+ Revision: 1643739
- new version 8.0.1
- drop mentions of sane subpackage, that doesn't exist anymore

* Tue Sep 08 2020 guillomovitch <guillomovitch> 7.2.0-1.mga8
+ Revision: 1623666
- new version 7.2.0

* Tue Apr 28 2020 daviddavid <daviddavid> 7.1.2-1.mga8
+ Revision: 1572825
- new version: 7.1.2

* Sat Apr 04 2020 daviddavid <daviddavid> 7.1.1-1.mga8
+ Revision: 1564255
- new version: 7.1.1

* Thu Feb 20 2020 umeabot <umeabot> 7.0.0-2.mga8
+ Revision: 1546105
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 7.0.0-1.mga8
+ Revision: 1485933
- new version: 7.0.0

* Thu Jan 16 2020 shlomif <shlomif> 6.2.2-1.mga8
+ Revision: 1478164
- New version 6.2.2 - MGA#25968

* Mon Dec 23 2019 shlomif <shlomif> 6.2.1-2.mga8
+ Revision: 1469736
- Add a provides for "PIL".

* Wed Nov 13 2019 daviddavid <daviddavid> 6.2.1-1.mga8
+ Revision: 1459724
- new version: 6.2.1

* Thu Oct 10 2019 daviddavid <daviddavid> 6.2.0-1.mga8
+ Revision: 1450908
- new version: 6.2.0
+ wally <wally>
- add patch to fix linking
- drop python2 leftover BRs

* Fri Sep 13 2019 tv <tv> 6.1.0-2.mga8
+ Revision: 1440544
- "fix" underlinking
- drop BR on python-numpy
- drop BR on python-setuptools
- rebuild for python-3.8
- drop python2 subpkg

* Sat Aug 24 2019 wally <wally> 6.1.0-1.mga8
+ Revision: 1431788
- new version 6.1.0
- update doc build
- build with libimagequant and openjpeg

* Fri Jan 11 2019 kekepower <kekepower> 5.4.1-1.mga7
+ Revision: 1354964
- Update to version 5.4.1

* Sat Jan 05 2019 wally <wally> 5.3.0-2.mga7
+ Revision: 1349857
- rebuild for python3.7

* Fri Dec 28 2018 luigiwalser <luigiwalser> 5.3.0-1.mga7
+ Revision: 1345815
- 5.3.0

* Sun Sep 23 2018 umeabot <umeabot> 4.3.0-4.mga7
+ Revision: 1300545
- Mageia 7 Mass Rebuild

* Sun Apr 29 2018 joequant <joequant> 4.3.0-3.mga7
+ Revision: 1223473
- regenerate rpms

* Fri Apr 27 2018 luigiwalser <luigiwalser> 4.3.0-2.mga7
+ Revision: 1222745
- obsolete wrongly imported python-pil

* Mon Oct 16 2017 joequant <joequant> 4.3.0-1.mga7
+ Revision: 1172291
- upgrade to 4.3.0

* Thu Aug 03 2017 philippem <philippem> 4.2.1-1.mga7
+ Revision: 1134296
- update to 4.2.1

* Wed Oct 26 2016 luigiwalser <luigiwalser> 3.4.2-1.mga6
+ Revision: 1063598
- 3.4.2

* Wed Oct 12 2016 philippem <philippem> 3.4.1-1.mga6
+ Revision: 1060512
- update to 3.4.1

* Sun Apr 10 2016 philippem <philippem> 3.2.0-1.mga6
+ Revision: 1000067
- update to 3.2.0

* Mon Feb 08 2016 philippem <philippem> 3.1.1-1.mga6
+ Revision: 948936
- update to 3.1.1 (fix CVE-2016-2533, CVE-2016-0775, CVE-2016-0740)

* Thu Feb 04 2016 philippem <philippem> 3.1.0-2.mga6
+ Revision: 936143
- fix buffer overflow mga#17671

* Thu Jan 21 2016 daviddavid <daviddavid> 3.1.0-1.mga6
+ Revision: 926206
- new version: 3.1.0

* Sat Jan 02 2016 luigiwalser <luigiwalser> 3.0.0-4.mga6
+ Revision: 918205
- rebuild for libwebp

* Fri Oct 23 2015 luigiwalser <luigiwalser> 3.0.0-3.mga6
+ Revision: 894647
- add conflicts to fix upgrade for mga#16975

* Mon Oct 19 2015 philippem <philippem> 3.0.0-2.mga6
+ Revision: 892704
- Some Bytecode files were in the wrong rpm

* Sat Oct 10 2015 philippem <philippem> 3.0.0-1.mga6
+ Revision: 889373
- update to 3.0.0

* Thu Oct 08 2015 daviddavid <daviddavid> 2.9.0-2.mga6
+ Revision: 887342
- rebuild for python 3.5
- rebuild for tcl/tk 8.6.4

* Fri Aug 28 2015 philippem <philippem> 2.9.0-1.mga6
+ Revision: 870452
- update to 2.9.0, move python-sane in a new package

* Mon Mar 02 2015 luigiwalser <luigiwalser> 2.6.2-2.mga5
+ Revision: 817289
- bump release tag to fix upgrade from mga4 (mga#15392)

* Sat Jan 24 2015 philippem <philippem> 2.6.2-1.mga5
+ Revision: 812146
- Update to 2.6.2, security fix mga#15115

* Wed Oct 15 2014 umeabot <umeabot> 2.5.3-4.mga5
+ Revision: 750439
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.5.3-3.mga5
+ Revision: 726908
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.5.3-2.mga5
+ Revision: 688215
- Mageia 5 Mass Rebuild

* Thu Aug 21 2014 luigiwalser <luigiwalser> 2.5.3-1.mga5
+ Revision: 666105
- Update to 2.5.3 (Fix CVE-2014-3598, a DOS in the Jpeg2KImagePlugin)

* Fri Aug 15 2014 philippem <philippem> 2.5.2-1.mga5
+ Revision: 662700
- Update to 2.5.2 (Fix CVE-2014-3589, a DOS in the IcnsImagePlugin)

* Mon Aug 11 2014 philippem <philippem> 2.5.1-1.mga5
+ Revision: 661679
- update to 2.5.1

* Thu Jul 03 2014 philippem <philippem> 2.5.0-1.mga5
+ Revision: 642788
- update to 2.5.0

* Sun Jun 01 2014 pterjan <pterjan> 2.4.0-0.2.mga5
+ Revision: 630390
- Soften python3 dependency
- Rebuild for new Python
+ daviddavid <daviddavid>
- fix description on main python3-pillow package

* Fri Apr 04 2014 philippem <philippem> 2.4.0-0.1.mga5
+ Revision: 611707
- update to 2.4.0

* Sun Mar 23 2014 luigiwalser <luigiwalser> 2.3.1-0.1.mga5
+ Revision: 606963
- 2.3.1 (fixes CVE-2014-1932 and CVE-2014-1933)

* Sat Feb 15 2014 luigiwalser <luigiwalser> 2.3.0-0.1.mga5
+ Revision: 592373
- update to 2.3.0 (sync with fedora)
- change lcms BR to lcms2
- add patches from fedora (including one to fix a test)
- add missing ghostscript Requires and BuildRequires (from fedora)
- add upstream patch to fix build with freetype 2.5
- rebuild for libwebp

* Tue Oct 22 2013 umeabot <umeabot> 2.2.1-0.3.mga4
+ Revision: 544030
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.2.1-0.2.mga4
+ Revision: 499118
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Oct 04 2013 philippem <philippem> 2.2.1-0.1.mga4
+ Revision: 491495
- Update to 2.2.1

* Sat Sep 07 2013 philippem <philippem> 2.1.0-0.2.mga4
+ Revision: 475735
- Add patch to fix memory corruption caused by invalid palette size, mga#10729

* Mon Jul 08 2013 philippem <philippem> 2.1.0-0.1.mga4
+ Revision: 451502
- Update to 2.1.0
- Update to 2.1.0

* Wed Jul 03 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.4.mga4
+ Revision: 449875
- obsolete old PIL

* Mon Jul 01 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.3.mga4
+ Revision: 448886
+ rebuild (emptylog)

* Sat Jun 29 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.2.mga4
+ Revision: 448390
- add provides

* Sat Jun 29 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.1.mga4
+ Revision: 448268
- fix groups
- add Python3
- add missing BR
- imported package python-pillow

